#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <SDL.h>
#include "SDL_ttf.h"

/* GP2X button mapping */
enum MAP_KEY
{
	VK_UP         , // 0
	VK_UP_LEFT    , // 1
	VK_LEFT       , // 2
	VK_DOWN_LEFT  , // 3
	VK_DOWN       , // 4
	VK_DOWN_RIGHT , // 5
	VK_RIGHT      , // 6
	VK_UP_RIGHT   , // 7
	VK_START      , // 8
	VK_SELECT     , // 9
	VK_FL         , // 10
	VK_FR         , // 11
	VK_FA         , // 12
	VK_FB         , // 13
	VK_FX         , // 14
	VK_FY         , // 15
	VK_VOL_UP     , // 16
	VK_VOL_DOWN   , // 17
	VK_TAT          // 18
};

/* The screen surface, joystick device */
SDL_Surface *screen = NULL;
SDL_Joystick *joy = NULL;
TTF_Font* font;

typedef unsigned char u8;

void Terminate(void)
{
	SDL_FreeSurface(screen);														// Release the memory allocated to screen
	//SDL_FreeSurface(sprite);														// Release the memory allocated to sprite
	//SDL_FreeSurface(rotosprite);													// Release the memory allocated to rotosprite
	//Mix_FreeChunk(sound);															// Release the memory allocated to sound
	//Mix_FreeMusic(music);															// Release the memory allocated to music
	//Mix_CloseAudio();																// Close SDL_Mixer Audio
	TTF_CloseFont(font);															// Release the memory allocated to font
	TTF_Quit();																		// Close SDL_TTF
	
	#ifndef GP2X																	// if GP2X isnt defined (i.e. PC) close SDL 
		SDL_Quit();
	#endif

	#ifdef GP2X																		// if GP2X is defined return to menu
		chdir("/usr/gp2x");
		execl("/usr/gp2x/gp2xmenu", "/usr/gp2x/gp2xmenu", NULL);
	#endif
}
void drawText(SDL_Surface* screen, char* string, int x, int y, int fR, int fG, int fB)
{
	SDL_Color foregroundColor = { fR, fG, fB };
	SDL_Surface* textSurface =  TTF_RenderText_Blended(font,string, foregroundColor);
	SDL_Rect textLocation = { x, y, 0, 0 };
	SDL_BlitSurface(textSurface, NULL, screen, &textLocation);
	SDL_FreeSurface(textSurface);
}
void LoadFont(u8 size)
{
	font = TTF_OpenFont("./data/arial.ttf", size);
}
int main (int argc, char *argv[])
{
	int done;

	/* Initialize SDL */
	if (SDL_Init (SDL_INIT_VIDEO | SDL_INIT_AUDIO | SDL_INIT_JOYSTICK) < 0) {
		fprintf (stderr, "Couldn't initialize SDL: %s\n", SDL_GetError ());
		exit (1);
	}
	atexit (Terminate);

	SDL_ShowCursor(SDL_DISABLE);

	/* Set 320x240 16-bits video mode */
	screen = SDL_SetVideoMode (320, 240, 16, SDL_SWSURFACE);
	if (screen == NULL) {
		fprintf (stderr, "Couldn't set 320x240x16 video mode: %s\n", SDL_GetError ());
		exit (2);
	}

	/* Check and open joystick device */
	if (SDL_NumJoysticks() > 0) {
		joy = SDL_JoystickOpen(0);
		if(!joy) {
			fprintf (stderr, "Couldn't open joystick 0: %s\n", SDL_GetError ());
		}
	}
	TTF_Init();																				// Initialize SDL_TTF
	
	 LoadFont(12);
	/* font has loaded */
	if (font == NULL) {
			fprintf (stderr, "Could not load font");
			exit (2);
			
	}

#ifdef GP2X
	/* Only use GP2X code here */
#endif

#ifdef WIN32
	/* Only use Windows code here */
#endif

    
	done = 0;
	while (!done)
	{
        
		SDL_Event event;
        
		/* Check for events */
		while (SDL_PollEvent (&event))
		{
            
			switch (event.type)
			{
				case SDL_KEYDOWN:
					/* if press Ctrl + C, terminate program */
					if ( (event.key.keysym.sym == SDLK_c) && (event.key.keysym.mod & (KMOD_LCTRL | KMOD_RCTRL)) )
						done = 1;
					break;
				case SDL_KEYUP:
					break;
				case SDL_JOYBUTTONDOWN:
					/* if press Start button, terminate program */
					if ( event.jbutton.button == VK_START )
						done = 1;
					break;
				case SDL_JOYBUTTONUP:
					break;
				case SDL_QUIT:
					done = 1;
					break;
				default:
					break;
			}
		}

		/* Processing */
		SDL_FillRect(screen, NULL, SDL_MapRGB(screen->format, 255,0,0));
    	drawText(screen, "Telecoda's Test Program.", 10, 10, 0, 0, 0);
    	drawText(screen, "Telecoda's Test Program.", 9, 9, 255, 255, 255);
#ifdef GP2X
	/* Only use GP2X code here */
	   	drawText(screen, "Press start to exit", 10, 30, 0, 0, 0);
	   	drawText(screen, "Press start to exit", 9, 29, 255, 255, 255);
	
#endif

#ifdef WIN32
	/* Only use Windows code here */
	   	drawText(screen, "Press CTRL-C to exit", 10, 30, 0, 0, 0);
	   	drawText(screen, "Press CTRL-C to exit", 9, 29, 255, 255, 255);
	
#endif
        SDL_Flip(screen);
	}
	SDL_FillRect(screen, NULL, SDL_MapRGB(screen->format, 255,255,0));
    	drawText(screen, "Shutting down...", 10, 10, 0, 0, 0);
        SDL_Flip(screen);
	exit(0);
	
	return 0;
}

